@@ -49,12 +49,24 @@ class NerBenchmark(TokenClassificationBenchmark):
                  verbose: bool = False):
         id2label = ['B-LOC', 'I-LOC', 'B-ORG', 'I-ORG', 'B-PER',
                     'I-PER', 'B-MISC', 'I-MISC', 'O']
+        label_synonyms = [
+            ['B-Location', 'B-location', 'B-place', id2label[0]],
+            ['I-Location', 'I-location', 'I-place', id2label[1]],
+            ['B-Organization', 'B-organization', 'B-inst', id2label[2]],
+            ['I-Organization', 'I-organization', 'I-inst', id2label[3]],
+            ['B-Person', 'B-person', id2label[4]],
+            ['I-Person', 'I-person', id2label[5]],
+            ['B-Miscellaneous', 'B-Misc', 'B-misc', id2label[6]],
+            ['I-Miscellaneous', 'I-Misc', 'I-misc', id2label[7]],
+            [id2label[8]]
+        ]
         super().__init__(name=name,
                          metric_names=dict(micro_f1='Micro-average F1-score',
                                            micro_f1_no_misc='Micro-average '
                                                             'F1-score without '
                                                             'MISC tags'),
                          id2label=id2label,
+                         label_synonyms=label_synonyms,
                          cache_dir=cache_dir,
                          evaluate_train=evaluate_train,
                          verbose=verbose)
